import type { PinchAndZoomOptions } from '../../types.js';
/**
 *
 * Performs a pinch gesture on the given element on the screen.
 *
 * :::info
 *
 * Pinching is done based on native mobile gestures. It is only supported for the following drivers:
 * - [appium-uiautomator2-driver](https://github.com/appium/appium-uiautomator2-driver/blob/master/docs/android-mobile-gestures.md#mobile-pinchclosegesture) for Android
 * - [appium-xcuitest-driver](https://appium.github.io/appium-xcuitest-driver/latest/reference/execute-methods/#mobile-pinch) for iOS
 *
 * :::
 *
 * <example>
    :pinch.js
    it('should demonstrate a pinch on Google maps', async () => {
        const mapsElement = $('//*[@resource-id="com.google.android.apps.maps:id/map_frame"]')
        // Pinch with the default duration scale
        await mapsElement.pinch()
        // Pinch with a custom duration and scale
        await mapsElement.pinch({ duration: 4000, scale: 0.9 })
    })
 * </example>
 *
 * @alias element.pinch
 * @param {PinchOptions=} options           pinch options (optional)
 * @param {number=}       options.duration  The duration in millisecond of how fast the pinch should be executed, minimal is 500 ms and max is 10000 ms. The default is 1500 ms (1.5 seconds) (optional)
 * @param {number=}       options.scale     The scale of how big the pinch should be according to the screen. Valid values must be float numbers in range 0..1, where 1.0 is 100% (optional)
 */
export declare function pinch(this: WebdriverIO.Element, options?: Partial<PinchAndZoomOptions>): Promise<unknown>;
//# sourceMappingURL=pinch.d.ts.map